@@ -18,13 +18,14 @@ eval {
     1;
 } or croak 'Can not load Mock::LWP::UserAgent. Code must be run from the base directory of the Astro-SpaceTrack distribution';
 
-our $VERSION = '0.092_02';
+our $VERSION = '0.093_01';
 
 {
     my $json;
     my $keep;
 
-    sub _censor_json {
+    # Accessed via address space scan in _list_censors()
+    sub _censor_json {	## no critic (ProhibitUnusedPrivateSubroutines)
 	my ( $data ) = @_;
 	$data =~ m/ \A \s* [[] \s* [{] .* [}] \s* []] \s* \z /smx
 	    or return;
@@ -62,32 +63,33 @@ our $VERSION = '0.092_02';
 	    }
 	    $item->{TLE_LINE1} =~ s/
 		    (?: \A | (?<= [\r\n] ) )
-		    1 [\s0-9]{6}U \s \K
+		    ( 1 [\s0-9]{6}U \s )
 		    [^\r\n]*
-		/First line of data/smxg;
+		/${1}First line of data/smxg;
 	    $item->{TLE_LINE2} =~ s/
 		    (?: \A | (?<= [\r\n] ) )
-		    2 [\s0-9]{6} \s \K
+		    ( 2 [\s0-9]{6} \s )
 		    [^\r\n]*
-		/Second line of data/smxg;
+		/${1}Second line of data/smxg;
 	}
 	return $json->encode( $a );
     }
 }
 
-sub _censor_tle {
+# Accessed via address space scan in _list_censors()
+sub _censor_tle {	## no critic (ProhibitUnusedPrivateSubroutines)
     my ( $data ) = @_;
     $data =~ s/
 	(?: \A | (?<= [\r\n] ) )
-	1 [\s0-9]{6}U \s \K
+	( 1 [\s0-9]{6}U \s )
 	[^\r\n]*
-    /First line of data/smxg
+    /${1}First line of data/smxg
 	or return;
     $data =~ s/
 	(?: \A | (?<= [\r\n] ) )
-	2 [\s0-9]{6} \s \K
+	( 2 [\s0-9]{6} \s )
 	[^\r\n]*
-    /Second line of data/smxg
+    /${1}Second line of data/smxg
 	or return;
     return $data;
 }
