@@ -9,7 +9,8 @@ use Carp;
 
 
 sub ACTION_authortest {
-    my ( $self, @args ) = @_;
+##  my ( $self, @args ) = @_;
+    my ( $self ) = @_;		# Arguments not used
 
     local $ENV{AUTHOR_TESTING} = 1;
 
@@ -20,6 +21,17 @@ sub ACTION_authortest {
     return;
 }
 
+sub harness_switches {
+    my ( $self ) = @_;
+    my @res = $self->SUPER::harness_switches();
+    foreach ( @res ) {
+	'-MDevel::Cover' eq $_
+	    or next;
+	$_ .= '=-db,cover_db,-ignore,inc/';
+    }
+    return @res;
+}
+
 1;
 
 __END__
